"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@typescript-eslint/utils");
const unnecessary_async_1 = require("../rules/unnecessary-async");
const ruleTester = new utils_1.ESLintUtils.RuleTester({
    parser: "@typescript-eslint/parser",
    parserOptions: {
        tsconfigRootDir: __dirname,
        project: "./tsconfig.json",
    },
});
ruleTester.run("unnecessary-async", unnecessary_async_1.default, {
    valid: [
        `
    async function b() {
      return Promise.resolve();
    };`,
        `function a() {
      return Promise.resolve();
    };
    async function b() {
      await a();
    };`,
        `function a() {
        return Promise.resolve();
      };
      async function b() {
        return a();
      };`,
    ],
    invalid: [
        {
            code: `
      async function b() {
        return 'Not returning a Promise explicitly';
      };
      `,
            errors: [{ messageId: "unnecessaryAsync" }],
        },
        {
            code: `
      function a() {
        return Promise.resolve();
      };
      async function b() {
        a();
      };`,
            errors: [
                { messageId: "unnecessaryAsync" },
            ],
        },
    ],
});
